"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var httpClient_1 = __importDefault(require("./httpClient"));
/**
 * Treat client and server as if originating from the same domain, and whatever
 * URL the client is at, the server has the corresponding URL that contains the
 * data. This is assuming there is a subdomain called "api" for the server at
 * the same domain.
 *
 * e.g.
 * client -> https://localhost:8000/users/
 * server -> https://api.localhost:8000/users/1
 */
function createRelativeHTTPClient(_a, client) {
    var location = _a.location;
    function getFullURL(url) {
        var origin = location.origin;
        return origin + "/api" + url;
    }
    return {
        fetch: function (url, config) {
            var fullURL = getFullURL(url);
            return client.fetch(fullURL, config);
        }
    };
}
exports.createRelativeHTTPClient = createRelativeHTTPClient;
/* istanbul ignore next */
exports.default = createRelativeHTTPClient(window, httpClient_1.default);
